@@ -1,19 +1,19 @@
 import re
 import boto3
-from mabledsocli.exceptions import DSOException
-from mabledsocli.logger import Logger
-from mabledsocli.config import Configs
-from mabledsocli.providers import Providers
-from mabledsocli.templates import TemplateProvider
-from mabledsocli.stages import Stages
-from mabledsocli.constants import *
-from mabledsocli.dict_utils import set_dict_value
-from mabledsocli.contexts import Contexts
-from mabledsocli.aws_utils import *
+from dsocli.exceptions import DSOException
+from dsocli.logger import Logger
+from dsocli.config import Configs
+from dsocli.providers import Providers
+from dsocli.templates import TemplateProvider
+from dsocli.stages import Stages
+from dsocli.constants import *
+from dsocli.dict_utils import set_dict_value
+from dsocli.contexts import Contexts
+from dsocli.aws_utils import *
 
 
 _default_spec = {
-    'prefix': '/dso/v1/templates'
+    'prefix': '/dso/v1/templates',
 }
 
 def get_default_spec():
@@ -73,6 +73,8 @@ class AwsSsmTemplateProvider(TemplateProvider):
     def add(self, project, application, stage, key, contents):
         if len(contents) > 4096:
             raise DSOException(f"This template provider does not support templates larger than 4KB.")
+        if not Stages.is_default(stage) and not Configs.allow_stage_templates:
+            raise DSOException(f"Stage templates are not allowed. You may enable this feature using 'allowStageTemplates'in the DSO application configuration.")
         Logger.debug(f"Checking SSM template overwrites: project={project}, application={application}, stage={stage}, key={key}")
         assert_ssm_parameter_no_namespace_overwrites(project, application, stage, key, prefix=self.get_prefix())
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
